@@ -47,15 +47,23 @@ struct aws_future_impl {
         aws_future_impl_result_release_fn *release;
     } result_dtor;
     int error_code;
-    /* sum of bit fields should be 32 */
-#define BIT_COUNT_FOR_SIZEOF_RESULT 27
-    unsigned int sizeof_result : BIT_COUNT_FOR_SIZEOF_RESULT;
-    unsigned int type : 3; /* aws_future_type */
-    unsigned int is_done : 1;
-    unsigned int owns_result : 1;
+
+    size_t sizeof_result;
+    enum aws_future_type type;
+    bool is_done;
+    bool owns_result;
 };
 
 static void s_future_impl_result_dtor(struct aws_future_impl *future, void *result_addr) {
+
+/*
+ * On ARM machines, the compiler complains about the array bounds warning for aws_future_bool, even though
+ * aws_future_bool will never go into any destroy or release branch. Disable the warning since it's a false positive.
+ */
+#ifndef _MSC_VER
+#    pragma GCC diagnostic push
+#    pragma GCC diagnostic ignored "-Warray-bounds"
+#endif
     switch (future->type) {
         case AWS_FUTURE_T_BY_VALUE_WITH_CLEAN_UP: {
             future->result_dtor.clean_up(result_addr);
@@ -79,6 +87,9 @@ static void s_future_impl_result_dtor(struct aws_future_impl *future, void *resu
         default:
             break;
     }
+#ifndef _MSC_VER
+#    pragma GCC diagnostic pop
+#endif
 }
 
 static void s_future_impl_destroy(void *user_data) {
@@ -96,9 +107,7 @@ static struct aws_future_impl *s_future_impl_new(struct aws_allocator *alloc, si
     struct aws_future_impl *future = aws_mem_calloc(alloc, 1, total_size);
     future->alloc = alloc;
 
-    /* we store sizeof_result in a bit field, ensure the number will fit */
-    AWS_ASSERT(sizeof_result <= (UINT_MAX >> (32 - BIT_COUNT_FOR_SIZEOF_RESULT)));
-    future->sizeof_result = (unsigned int)sizeof_result;
+    future->sizeof_result = sizeof_result;
 
     aws_ref_count_init(&future->ref_count, future, s_future_impl_destroy);
     aws_mutex_init(&future->lock);
@@ -174,7 +183,7 @@ bool aws_future_impl_is_done(const struct aws_future_impl *future) {
 
     /* BEGIN CRITICAL SECTION */
     aws_mutex_lock(mutable_lock);
-    bool is_done = future->is_done != 0;
+    bool is_done = future->is_done;
     aws_mutex_unlock(mutable_lock);
     /* END CRITICAL SECTION */
 
@@ -350,7 +359,7 @@ static bool s_future_impl_register_callback(
 
     AWS_FATAL_ASSERT(future->callback.fn == NULL && "Future done callback must only be set once");
 
-    bool already_done = future->is_done != 0;
+    bool already_done = future->is_done;
 
     /* if not done, store callback for later */
     if (!already_done) {
@@ -444,7 +453,7 @@ void aws_future_impl_register_channel_callback(
 
 static bool s_future_impl_is_done_pred(void *user_data) {
     struct aws_future_impl *future = user_data;
-    return future->is_done != 0;
+    return future->is_done;
 }
 
 bool aws_future_impl_wait(const struct aws_future_impl *future, uint64_t timeout_ns) {
@@ -453,13 +462,16 @@ bool aws_future_impl_wait(const struct aws_future_impl *future, uint64_t timeout
     /* this function is conceptually const, but we need to use synchronization primitives */
     struct aws_future_impl *mutable_future = (struct aws_future_impl *)future;
 
+    /* condition-variable takes signed timeout, so clamp to INT64_MAX (292+ years) */
+    int64_t timeout_i64 = aws_min_u64(timeout_ns, INT64_MAX);
+
     /* BEGIN CRITICAL SECTION */
     aws_mutex_lock(&mutable_future->lock);
 
     bool is_done = aws_condition_variable_wait_for_pred(
                        &mutable_future->wait_cvar,
                        &mutable_future->lock,
-                       (int64_t)timeout_ns,
+                       timeout_i64,
                        s_future_impl_is_done_pred,
                        mutable_future) == AWS_OP_SUCCESS;
 
@@ -469,60 +481,7 @@ bool aws_future_impl_wait(const struct aws_future_impl *future, uint64_t timeout
     return is_done;
 }
 
-// AWS_FUTURE_T_BY_VALUE_IMPLEMENTATION(aws_future_bool, bool)
-struct aws_future_bool *aws_future_bool_new(struct aws_allocator *alloc) {
-    return (struct aws_future_bool *)aws_future_impl_new_by_value(alloc, sizeof(_Bool));
-}
-void aws_future_bool_set_result(struct aws_future_bool *future, _Bool result) {
-    aws_future_impl_set_result_by_move((struct aws_future_impl *)future, &result);
-}
-_Bool aws_future_bool_get_result(const struct aws_future_bool *future) {
-    return *(_Bool *)aws_future_impl_get_result_address((const struct aws_future_impl *)future);
-}
-struct aws_future_bool *aws_future_bool_acquire(struct aws_future_bool *future) {
-    return (struct aws_future_bool *)aws_future_impl_acquire((struct aws_future_impl *)future);
-}
-struct aws_future_bool *aws_future_bool_release(struct aws_future_bool *future) {
-    return (struct aws_future_bool *)aws_future_impl_release((struct aws_future_impl *)future);
-}
-void aws_future_bool_set_error(struct aws_future_bool *future, int error_code) {
-    aws_future_impl_set_error((struct aws_future_impl *)future, error_code);
-}
-_Bool aws_future_bool_is_done(const struct aws_future_bool *future) {
-    return aws_future_impl_is_done((const struct aws_future_impl *)future);
-}
-int aws_future_bool_get_error(const struct aws_future_bool *future) {
-    return aws_future_impl_get_error((const struct aws_future_impl *)future);
-}
-void aws_future_bool_register_callback(
-    struct aws_future_bool *future,
-    aws_future_callback_fn *on_done,
-    void *user_data) {
-    aws_future_impl_register_callback((struct aws_future_impl *)future, on_done, user_data);
-}
-_Bool aws_future_bool_register_callback_if_not_done(
-    struct aws_future_bool *future,
-    aws_future_callback_fn *on_done,
-    void *user_data) {
-    return aws_future_impl_register_callback_if_not_done((struct aws_future_impl *)future, on_done, user_data);
-}
-void aws_future_bool_register_event_loop_callback(
-    struct aws_future_bool *future,
-    struct aws_event_loop *event_loop,
-    aws_future_callback_fn *on_done,
-    void *user_data) {
-    aws_future_impl_register_event_loop_callback((struct aws_future_impl *)future, event_loop, on_done, user_data);
-}
-void aws_future_bool_register_channel_callback(
-    struct aws_future_bool *future,
-    struct aws_channel *channel,
-    aws_future_callback_fn *on_done,
-    void *user_data) {
-    aws_future_impl_register_channel_callback((struct aws_future_impl *)future, channel, on_done, user_data);
-}
-_Bool aws_future_bool_wait(struct aws_future_bool *future, uint64_t timeout_ns) {
-    return aws_future_impl_wait((struct aws_future_impl *)future, timeout_ns);
-}
+AWS_FUTURE_T_BY_VALUE_IMPLEMENTATION(aws_future_bool, bool)
 
 AWS_FUTURE_T_BY_VALUE_IMPLEMENTATION(aws_future_size, size_t)
 
